<?php
$this->load->library('ciext/ciext');
$this->ciext->load_jquery();
$this->js_css->parse_css('callme/css/valid.css');
$this->js_css->parse_js('callme/js/validator.js');
$this->js_css->parse_js('callme/js/valid.js');
?>
<h2>{ln_info}</h2>
{form_open}
<?= $hash ?>
    <div class="form_left">
        <input type="text" maxlength="40" name="name" placeholder="{ln_name}">
        <input type="text" maxlength="40" name="email" placeholder="{ln_email}">
        <input type="text" maxlength="16" name="phone" placeholder="{ln_phone}"> 
        <input class="send" name="submit" type="submit" value="{ln_send}" />
    </div>
    <label id="message" style="display:none">{msg_ok}</label>
    <div class="form_right">
        <textarea name="text" placeholder="{ln_text}"></textarea>
    </div>
{form_close}