var validatorMinLength = function(str, length) {
    
    return (str.length >= length);
};

var validatorMaxLength = function(str, length) {
    
    return (str.length <= length);
};

var validatorIsText = function(str) {
    var expr = /[А-Яa-z]+/gi;
    
    return expr.test(str);
};

var validatorIsDigit = function(str) {
    var expr = /[\d]+/gi;
    
    return expr.test(str);
};

var validatorIsName = function(str) {
    var newStr = str.split(" ").join("");
    
    return (validatorMinLength(newStr, 3) && validatorIsText(newStr));
};

var validatorIsPhone = function(str) {
    var newStr = str.split(" ").join("").split("+").join("").split("(").join("").split(")").join("").split("-").join("");
    var expr = /[\d]+/gi;
    
    return (validatorMinLength(newStr, 5) && validatorMaxLength(newStr, 12) && expr.test(newStr));
};

var validatorIsEmail = function(str) {
    var expr = /^(([^<>()[\]\\.,;:\s@\"]+(\.[^<>()[\]\\.,;:\s@\"]+)*)|(\".+\"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/;
    
    return expr.test(str);
};