<?php 

$lang['title'] = 'Перегляд запитів з сайту';

$lang['display_as'] = array(
    'name' => 'Ім\'я',
    'text' => 'Повідомлення',
    'phone' => 'Телефон',
    'email' => 'Email',
    'date_add' => 'Дата звернення',
    'worked_out' => 'Відпрацьований'
);

$lang['config_title'] = $lang['title'] . '/Налаштування';


$lang['msg_ok'] = 'Дані змінено';
$lang['btn_save'] = 'Зберегти';

$lang['config_aliases'] = array(
    'email' => '<p><b>Email для отправки повідомлення.</b></p>якщо пусто - повідомлення не відправляється',
    'subject' => '<b>Тема повідомлення</b>',
    'template' => '<p><b>Шаблон повідомлення.</b></p>'
    . '<p>Змінні нижче замінюються на дані користувача:</p> '
    . '<p>{in_name} - ім\'я</p>'
    . '<p>{in_email} - E-mail</p>'
    . '<p>{in_phone} - телефон</p>'
    . '<p>{in_text} - текс</p>',
);