<?php 

$lang['ln_info'] = 'Форма зворотнього зв\'язку';
$lang['ln_name'] = 'Ваше ім\'я';
$lang['ln_email'] = 'E-mail';
$lang['ln_phone'] = 'Телефон';
$lang['ln_text'] = 'Повідомлення';
$lang['ln_send'] = 'Відправити заявку';

$lang['msg_ok'] = 'Дані відправлені';
$lang['User ask question'] = 'Користувач "%s" задав питання. <a href="%s">Детальніше</a>';