<?php

$lang['module_name'] = 'Обратная связь';

$lang['module_actions'] = array(
    // 'acl_action' => 'description'
    'manager' => 'Просмотр запросов',
    'delete' => 'Удаление запросов',
    'configuration' => 'Настройка'
);

$lang['module_menu_items'] = array(
//    array('method in admin controller', 'title in menu', 'path to the image. empty - default image', 'acl_action')
    array('manager', $lang['module_actions']['manager'], '', 'manager'),
    array('configuration', $lang['module_actions']['configuration'], '', 'configuration')
);