<?php 

$lang['ln_info'] = 'Call me form';
$lang['ln_name'] = 'Name';
$lang['ln_email'] = 'E-mail';
$lang['ln_phone'] = 'Phone';
$lang['ln_text'] = 'Message';
$lang['ln_send'] = 'Send';

$lang['msg_ok'] = 'Sended';
$lang['User ask question'] = 'User "%s" ask question. <a href="%s">Detail</a>';
