<?php 

$lang['ln_info'] = 'Форма обратной связи';
$lang['ln_name'] = 'Имя';
$lang['ln_email'] = 'E-mail';
$lang['ln_phone'] = 'Телефон';
$lang['ln_text'] = 'Сообщение';
$lang['ln_send'] = 'Отправить сообщение';

$lang['msg_ok'] = 'Данные отправлены';
$lang['User ask question'] = 'Пользователь "%s" задал вопрос. <a href="%s">Подробнее</a>';
