<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

$config['upgrade_callme'] = [
    [
        'version' => '0',
        'library' => 'callme/migrations/callme_upgrade_0',
    ],
];
